import { BasicColumn, FormSchema } from '/@/components/Table';
import { optionsListApi, optionTypeListApi } from '/@/api/tigerapi/wms/enterwarehouse';
import { h, unref } from 'vue';
import { Tag, Tooltip } from 'ant-design-vue';
import { useI18n } from '/@/hooks/web/useI18n';
import { useLocale } from '/@/locales/useLocale';
const { t: bt } = useI18n();
const { getLocale } = useLocale();

export const columns: BasicColumn[] = [
  {
    title: '单据代码',
    dataIndex: 'BILLCODE',
    resizable: true,
    sorter: true,
    width: 200,
  },
  {
    title: '收料单',
    dataIndex: 'ERP_BILL_CODE',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: '单据日期',
    dataIndex: 'BILLDATE',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: bt('创建时间'),
    dataIndex: 'CREATE_TIME',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: bt('修改时间'),
    dataIndex: 'UPDATE_TIME',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: bt('T100单据代码'),
    dataIndex: 'ERP_BILL_CODE',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: '单据状态',
    dataIndex: 'STATUS',
    resizable: true,
    sorter: true,
    width: 180,
    customRender: ({ record }) => {
      const status = record.STATUS;
      let text = '';
      let color = '';
      switch (status) {
        case 0:
          text = '新增';
          color = '#C2C247';
          break;
        case 1:
          text = '作业中';
          color = '#C2C247';
          break;
        case 2:
          text = '完成';
          color = 'blue';
          break;
        default:
          break;
      }
      return h(Tag, { color: color }, () => text);
    },
  },
  {
    title: '供应商名称',
    dataIndex: 'SUPPLIERCODE',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: '单据类型',
    dataIndex: 'BIZTYPE',
    resizable: true,
    sorter: true,
    width: 180,
    customRender: ({ record }) => {
      const status = record.BIZTYPE;
      let text = '';
      let color = '';
      switch (status) {
        case 1:
          text = '采购';
          color = 'green';
          break;
        case 2:
          text = '委外';
          color = 'blue';
          break;
        case 99:
          text = '其他';
          color = '#C2C247';
          break;
        default:
          break;
      }
      return h(Tag, { color: color }, () => text);
    },
  },
  {
    title: '创建人',
    dataIndex: 'CREATE_USER',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: '创建时间',
    dataIndex: 'CREATE_TIME',
    resizable: true,
    sorter: true,
    width: 180,
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'BILLCODE',
    label: '单据代码',
    colProps: { span: 8 },
    component: 'Input',
  },
  {
    field: 'ERP_BILL_CODE',
    label: '收料单',
    colProps: { span: 8 },
    component: 'Input',
  },
  {
    field: 'BILLDATE',
    label: '单据日期',
    colProps: { span: 8 },
    component: 'RangePicker',
  },
  {
    field: 'STATUS',
    label: '单据状态',
    component: 'ApiSelect',
    componentProps: {
      api: optionsListApi,
      resultField: 'Data',
      labelField: 'Desc',
      valueField: 'Value',
      // onChange: (e, v) => {
      //   alert(e)
      //   console.log('ApiSelect====>:', e, v);
      // },
    },
    colProps: { span: 8 },
  },
  {
    field: 'BIZTYPE',
    label: '单据类型',
    component: 'ApiSelect',
    componentProps: {
      api: optionTypeListApi,
      resultField: 'Data',
      labelField: 'Desc',
      valueField: 'Value',
      // onChange: (e, v) => {
      //   alert(e)
      //   console.log('ApiSelect====>:', e, v);
      // },
    },
    colProps: { span: 8 },
  },
  // {
  //   field: 'STATUS',
  //   label: '状态',
  //   component: 'Select',
  //   colProps: { span: 8 },
  //   componentProps: {
  //     options: [
  //       {
  //         label: '新建',
  //         value: 0,
  //         key: 0,
  //       },
  //       {
  //         label: '待检',
  //         value: 1,
  //         key: 1,
  //       },
  //       {
  //         label: '检验中',
  //         value: 2,
  //         key: 2,
  //       },
  //       {
  //         label: '完成',
  //         value: 3,
  //         key: 3,
  //       }
  //     ],
  //   },

  // },
];

//领料单(WMS)明细
export const columns_D: BasicColumn[] = [
  {
    title: bt('序号'),
    dataIndex: 'BILLLINE',
    resizable: true,
    sorter: true,
    width: 100,
  },
  {
    title: bt('料号'),
    dataIndex: 'ITEM_CODE',
    resizable: true,
    sorter: true,
    width: 200,
  },
  {
    title: '来料数量',
    dataIndex: 'QTY',
    resizable: true,
    sorter: true,
    width: 100,
  }, {
    title: '已入数量',
    dataIndex: 'INSTOCKQTY',
    resizable: true,
    sorter: true,
    width: 100,
  },
  {
    title: '差异数量',
    dataIndex: 'OWEIN_QTY',
    resizable: true,
    sorter: true,
    width: 100,
  },
  {
    title: bt('单据代码'),
    dataIndex: 'BILLCODE',
    resizable: true,
    sorter: true,
    width: 200,
  },
  {
    title: bt('修改时间'),
    dataIndex: 'UPDATE_TIME',
    resizable: true,
    sorter: true,
    width: 180,
  },
  // {
  //   title: bt('单据类型'),
  //   dataIndex: 'BIZTYPE',
  //   resizable:true,
  //   customRender: ({ record }) => {
  //     const status = record.BIZTYPE;
  //     var text = '';
  //     var color = '';
  //     switch (status) {
  //       case '1':
  //         text = bt('采购');
  //         color = 'green';
  //         break;
  //       case '2':
  //         text = bt('委外');
  //         color = 'blue';
  //         break;
  //       // case '99':
  //       //   text = '其他';
  //       //   color = '#C2C247';
  //       //   break;
  //       default:
  //         break;
  //     }
  //     return h(Tooltip, { title: 'xxxxxx' }, () => h(Tag, { color: color }, () => text));
  //   },
  // },
  {
    title: bt('状态'),
    dataIndex: 'LINESTATUS',
    resizable: true,
    sorter: true,
    width: 180,
    customRender: ({ record }) => {
      console.log('record', record);
      const status = record.LINESTATUS;
      let text = '';
      let color = '';
      switch (status) {
        case 0:
          text = '新增';
          color = '#C2C247';
          break;
        case 1:
          text = '作业中';
          color = '#C2C247';
          break;
        case 2:
          text = '完成';
          color = 'blue';
          break;
        default:
          break;
      }
      return h(Tag, { color: color }, () => text);
    },
  },
]

export const columns_S: BasicColumn[] = [
  {
    title: bt('组织机构授权标识字段'),
    dataIndex: 'AUTH_ORG',
    resizable: true,
    sorter: true,
    width: 200,
    ifShow: false
  },
  {
    title: bt('生产单元授权标识字段'),
    dataIndex: 'AUTH_PROD',
    resizable: true,
    sorter: true,
    width: 200,
    ifShow: false
  },
  {
    title: bt('仓库单元授权标识字段'),
    dataIndex: 'AUTH_WH',
    resizable: true,
    sorter: true,
    width: 200,
    ifShow: false
  },
  {
    title: bt('条码'),
    dataIndex: 'SN',
    resizable: true,
    sorter: true,
    width: 200,
  },
  {
    title: bt('修改时间'),
    dataIndex: 'UPDATE_TIME',
    resizable: true,
    sorter: true,
    width: 180,
  },
  // {
  //   title: bt('单据类型'),
  //   dataIndex: 'BIZTYPE',
  //   resizable:true,
  //   customRender: ({ record }) => {
  //     const status = record.BIZTYPE;
  //     var text = '';
  //     var color = '';
  //     switch (status) {
  //       case '1':
  //         text = bt('采购');
  //         color = 'green';
  //         break;
  //       case '2':
  //         text = bt('委外');
  //         color = 'blue';
  //         break;
  //       // case '99':
  //       //   text = '其他';
  //       //   color = '#C2C247';
  //       //   break;
  //       default:
  //         break;
  //     }
  //     return h(Tooltip, { title: 'xxxxxx' }, () => h(Tag, { color: color }, () => text));
  //   },
  // },
  {
    title: bt('状态'),
    dataIndex: 'STATUS',
    resizable:true,
    sorter: true,
    customRender: ({ record }) => {
      console.log('record', record);
      const status = record.STATUS;
      let text = '';
      let color = '';
      switch (status) {
        case 0:
          text = bt('不存在');
          color = 'blue';
          break;
        case 10:
          text = bt('送货中');
          color = '#C2C247';
          break;
        case 20:
          text = bt('待检验');
          color = '#C2C247';
          break;
        case 30:
          text = bt('待入库');
          color = '#C2C247';
          break;
        case 40:
          text = bt('在库中');
          color = 'green';
          break;
          case 50:
          text = bt('已下架');
          color = 'green';
          break;
          case 60:
          text = bt('已发料');
          color = 'green';
          break;
          case 70:
          text = bt('已上料');
          color = 'green';
          break;
          case 80:
          text = bt('已耗尽');
          color = 'green';
          break;
          case 90:
          text = bt('已退料');
          color = 'green';
          break;
          case 100:
            text = bt('已发货');
            color = 'green';
            break;
        default:
          break;
      }
      return h(Tag, { color: color }, () => text);
    },
    width: 200,
  },
  {
    title: bt('物料编码'),
    dataIndex: 'ITEM_CODE',
    resizable: true,
    sorter: true,
    width: 200,
  },
  {
    title: bt('扫描数量'),
    dataIndex: 'SCANQTY',
    resizable: true,
    sorter: true,
    width: 200,
  },
];

export const searchFormSchema_D: FormSchema[] = [
  {
    field: 'ITEM_CODE',
    label: bt('物料编码'),
    colProps: { span: 8 },
    component: 'Input',
  },
  {
    field: 'LINESTATUS',
    label: bt('状态'),
    component: 'ApiSelect',
    colProps: { span: 8 },
    componentProps: {
      api: optionsListApi,
      resultField: 'Data',
      labelField: unref(getLocale) == 'zh_CN' ? 'Desc' : 'Name',
      valueField: 'Value',
    },
  },
  // {
  //   field: 'BIZTYPE',
  //   label: bt('单据类型'),
  //   component: 'ApiSelect',
  //   colProps: { span: 8 },
  //   componentProps: {
  //     api: optionTypeListApi,
  //     resultField: 'Data',
  //     labelField: unref(getLocale)=='zh_CN'?'Desc':'Name',
  //     valueField: 'Value',
  //   },
  // },
];
export const searchFormSchema_S: FormSchema[] = [
  // {
  //   field: 'BILLCODE',
  //   label: bt('单据代码'),
  //   colProps: { span: 8 },
  //   component: 'Input',
  // },
  {
    field: 'ITEM_CODE',
    label: bt('物料编码'),
    colProps: { span: 8 },
    component: 'Input',
  },
  {
    field: 'SN',
    label: bt('条码'),
    colProps: { span: 8 },
    component: 'Input',
  },
  // {
  //   field: 'LINESTATUS',
  //   label: bt('状态'),
  //   component: 'ApiSelect',
  //   colProps: { span: 8 },
  //   componentProps: {
  //     api: optionsListApi,
  //     resultField: 'Data',
  //     labelField: unref(getLocale) == 'zh_CN' ? 'Desc' : 'Name',
  //     valueField: 'Value',
  //   },
  // },
  // {
  //   field: 'BIZTYPE',
  //   label: bt('单据类型'),
  //   component: 'ApiSelect',
  //   colProps: { span: 8 },
  //   componentProps: {
  //     api: optionTypeListApi,
  //     resultField: 'Data',
  //     labelField: unref(getLocale)=='zh_CN'?'Desc':'Name',
  //     valueField: 'Value',
  //   },
  // },
];
